/*
Ŀ
 w_get.h                                                                      
                                                                              
 The C User Interface Library                                                 
 Copyright 1992 Mathware, joneric Wennerstrom                                 

*/
/*
Ŀ
 Defines                                                                      

*/
#ifndef W_GET_H
#define W_GET_H
#if defined(__POWERC)                  /* Disable debug information for Power */
#pragma trace -                        /* Ctrace in headers.                  */
#endif                                 /*                                     */
#define MAX_NUM_GETS     256           /* Number of gets allowed              */
#define NUM_GET_TYPES     22           /* Number of supported gets types      */
#define CHAR               0           /* Get Types                           */
#define CHECKBOX           1           /*                                     */
#define DATE               2           /*                                     */
#define DOUBLE             3           /*                                     */
#define EXT_DATE           4           /*                                     */
#define EXT_TIME           5           /*                                     */
#define EXT_ZIP            6           /*                                     */
#define FILE_NAME          7           /*                                     */
#define FLOAT              8           /*                                     */
#define INT                9           /*                                     */
#define LONG_INT          10           /*                                     */
#define PASSWORD          11           /*                                     */
#define PHONE             12           /*                                     */
#define SOC_SEC           13           /*                                     */
#define STRING            14           /*                                     */
#define TIME              15           /*                                     */
#define TRUE_FALSE        16           /*                                     */
#define UNSIGNED_CHAR     17           /*                                     */
#define UNSIGNED_INT      18           /*                                     */
#define UNSIGNED_LONG_INT 19           /*                                     */
#define YES_NO            20           /*                                     */
#define ZIP               21           /*                                     */
/*
Ŀ
 Structures                                                                   

*/
typedef struct GET_ITEM
{
  WIN_PTR window;                      /* Window in which get will be done    */
  int     row,                         /* Window row where prompt will start  */
          col;                         /* Window col where prompt will start  */
  char   *prompt;                      /* Get prompt                          */
  int     get_type;                    /* Type of variable to edit            */
  void   *get_var;                     /* Address of variable being edited    */
  void   *edit_var;                    /* Edit copy of variable               */
  int     edit_col;                    /* Column after prompt where edit begin*/
  char   *mask;                        /* Edit mask                           */
  char   *buffer;                      /* Screen buffer used to edit variable */
  int     max_char,                    /* Length of screen edit buffer        */
          disp_flag;                   /* Display initial value or not        */
  char   *help_word;                   /* Help key word                       */
  int    (*valid)(void);               /* Valid function                      */
} GET_ITEM;
typedef struct GET_ITEM *GET_ITEM_PTR;

typedef struct GET_DATA
{
  int       num_gets;                  /* Number of pending gets              */
  int       cur_get;                   /* Index of currently active get       */
  GET_ITEM *get[MAX_NUM_GETS];         /* Pointer to an array of gets         */
} GET;
typedef struct GET_DATA *GET_PTR;
/*
Ŀ
 Function Prototypes                                                          

*/
extern void g_buffer_upd(void);
extern int  g_char(WIN_PTR window,int row,int col,char *prompt,
            char *char_var,int disp_flag,char *help_word,int (*valid)(void));
extern int  g_checkbox(WIN_PTR window,int row,int col,char *prompt,
            char *check_var,int disp_flag,char *help_word,int (*valid)(void));
extern void g_close(void);
extern int  g_date(WIN_PTR window,int row,int col,char *prompt,
            W_DATE *date,int disp_flag,char *help_word,int (*valid)(void));
extern int  g_double(WIN_PTR window,int row,int col,char *prompt,
            double *double_var,int max_char,int disp_flag,char *help_word,
            int (*valid)(void));
extern int  g_ext_date(WIN_PTR window,int row,int col,char *prompt,
            W_DATE *ext_date,int disp_flag,char *help_word,int (*valid)(void));
extern int  g_ext_time(WIN_PTR window,int row,int col,char *prompt,
            W_TIME *ext_time,int disp_flag,char *help_word,int (*valid)(void));
extern int  g_ext_zip(WIN_PTR window,int row,int col,char *prompt,
            char *ext_zip,int disp_flag,char *help_word,int (*valid)(void));
extern int  g_filename(WIN_PTR window,int row,int col,char *prompt,
            char *file,int max_char,int disp_flag,char *help_word,
            int (*valid)(void));
extern int  g_float(WIN_PTR window,int row,int col,char *prompt,
            float *float_var,int max_char,int disp_flag,char *help_word,
            int (*valid)(void));
extern int  g_int(WIN_PTR window,int row,int col,char *prompt,
            int *int_var,int max_char,int disp_flag,char *help_word,
            int (*valid)(void));
extern int  g_long(WIN_PTR window,int row,int col,char *prompt,
            long *long_var,int max_char,int disp_flag,char *help_word,
            int (*valid)(void));
extern int  g_password(WIN_PTR window,int row,int col,char *prompt,
            char *password,int max_char,char *help_word,int (*valid)(void));
extern int  g_phone(WIN_PTR window,int row,int col,char *prompt,
            char *phone,int disp_flag,char *help_word,int (*valid)(void));
extern void g_read(void);
extern int  g_set(WIN_PTR window,int get_type,void *var_ptr,int row,
            int col,char *prompt,int max_char,int disp_flag,char *help_word,
            int (*valid)(void));
extern int  g_soc_sec(WIN_PTR window,int row,int col,char *prompt,
            char *soc_sec,int disp_flag,char *help_word,int (*valid)(void));
extern int  g_string(WIN_PTR window,int row,int col,char *prompt,
            char *string,int max_char,int disp_flag,char *help_word,
            int (*valid)(void));
extern int  g_tf(WIN_PTR window,int row,int col,char *prompt,
            char *t_f,int disp_flag,char *help_word,int (*valid)(void));
extern int  g_time(WIN_PTR window,int row,int col,char *prompt,
            W_TIME *time,int disp_flag,char *help_word,int (*valid)(void));
extern int  g_unchar(WIN_PTR window,int row,int col,char *prompt,
            unsigned char *unchar_var,int disp_flag,char *help_word,
            int (*valid)(void));
extern int  g_unint(WIN_PTR window,int row,int col,char *prompt,
            unsigned int *unint_var,int max_char,int disp_flag,char *help_word,
            int (*valid)(void));
extern int  g_unlong(WIN_PTR window,int row,int col,char *prompt,
            unsigned long int *unlong_var,int max_char,int disp_flag,
            char *help_word,int (*valid)(void));
extern int  g_yn(WIN_PTR window,int row,int col,char *prompt,
            char *y_n,int disp_flag,char *help_word,int (*valid)(void));
extern int  g_zip(WIN_PTR window,int row,int col,char *prompt,
            char *zip,int disp_flag,char *help_word,int (*valid)(void));
extern int  def_val_char(void);        /* These are the default valid         */
extern int  def_val_chkbox(void);      /* functions that will get executed if */
extern int  def_val_date(void);        /* the user does not specify his own   */
extern int  def_val_double(void);      /* valid function.                     */
extern int  def_val_ext_date(void);    /*                                     */
extern int  def_val_ext_time(void);    /*                                     */
extern int  def_val_ext_zip(void);     /*                                     */
extern int  def_val_file_name(void);   /*                                     */
extern int  def_val_float(void);       /*                                     */
extern int  def_val_int(void);         /*                                     */
extern int  def_val_long(void);        /*                                     */
extern int  def_val_password(void);    /*                                     */
extern int  def_val_phone(void);       /*                                     */
extern int  def_val_soc_sec(void);     /*                                     */
extern int  def_val_string(void);      /*                                     */
extern int  def_val_tf(void);          /*                                     */
extern int  def_val_time(void);        /*                                     */
extern int  def_val_unchar(void);      /*                                     */
extern int  def_val_unint(void);       /*                                     */
extern int  def_val_unlong(void);      /*                                     */
extern int  def_val_yn(void);          /*                                     */
extern int  def_val_zip(void);         /*                                     */
#if defined(__POWERC)                  /* Re-enable debug information for     */
#pragma trace                          /* Power Ctrace in source files.       */
#endif                                 /*                                     */
#endif
