/*
Ŀ
 w_window.h                                                                   
                                                                              
 The C User Interface Library                                                 
 Copyright 1992 Mathware, joneric Wennerstrom                                 

*/
/*
Ŀ
 Defines                                                                      

*/
#ifndef W_WINDOW_H
#define W_WINDOW_H
#if defined(__POWERC)                  /* Disable debug information for Power */
#pragma trace -                        /* Ctrace in headers.                  */
#endif                                 /*                                     */
#define W_CLOSE         0              /* Window is closed                    */
#define W_OPEN          1              /* Window is open                      */
#define W_NO_BORDER     0              /* Bordered windows                    */
#define W_BORDER        1              /* Borderless windows                  */
#define W_NO_SHADOW     0              /* Shadowed windows                    */
#define W_SHADOW        1              /* Shadowless windows                  */
#define W_NO_TITLE      0              /* Titleless windows                   */
#define w_TAB           4              /* Tabs, '\t', expanded to 4 spaces    */
#define BLINK           128            /* Make a color blink                  */
#define W_DISK_ERROR    1              /* Whenever a disk error occurrs       */
/*
Ŀ
 COLORS                     

*/
#define B_BLACK         0x00           /* Default Background text mode colors */
#define B_BLUE          0x10           /* These color constants are used by   */
#define B_GREEN         0x20           /* v_setcolor.                         */
#define B_CYAN          0x30           /*                                     */
#define B_RED           0x40           /*                                     */
#define B_PURPLE        0x50           /*                                     */
#define B_BROWN         0x60           /*                                     */
#define B_GREY          0x70           /*                                     */
#define F_BLACK         0x00           /* Default Foreground text mode colors */
#define F_BLUE          0x01           /*                                     */
#define F_GREEN         0x02           /*                                     */
#define F_CYAN          0x03           /*                                     */
#define F_RED           0x04           /*                                     */
#define F_PURPLE        0x05           /*                                     */
#define F_BROWN         0x06           /*                                     */
#define F_GREY          0x07           /*                                     */
#define F_DARK_GREY     0x08           /*                                     */
#define F_BRIGHT_BLUE   0x09           /*                                     */
#define F_BRIGHT_GREEN  0x0A           /*                                     */
#define F_BRIGHT_CYAN   0x0B           /*                                     */
#define F_ORANGE        0x0C           /*                                     */
#define F_BRIGHT_PURPLE 0x0D           /*                                     */
#define F_YELLOW        0x0E           /*                                     */
#define F_WHITE         0x0F           /*                                     */
/*
Ŀ
 SCROLL DIRECTIONS          

*/
#define  UP          0                 /* Scroll a window up                  */
#define  DOWN        1                 /* Scroll a window down                */
#define  LEFT        0                 /* Scroll a window left                */
#define  RIGHT       1                 /* Scroll a window right               */
/*
Ŀ
 MOVE DIRECTIONS            

*/
#define  W_HORZ      0                 /* Move window horizontally            */
#define  W_VERT      1                 /* Move windo vertically               */
/*
Ŀ
 Border Types               

*/
#define  SINGLE_LINE 0                 /* Single line border                  */
#define  DOUBLE_LINE 1                 /* Double line border                  */
#define  SINGLE_DROP 2                 /* Single line drop down border        */
#define  DOUBLE_DROP 3                 /* Double line drop down border        */
/*
Ŀ
 Disk drive types           

*/
#define  DRIVE_NONE    0               /* Drive not present                   */
#define  DRIVE_360K    1               /* Drive type number as reported by    */
#define  DRIVE_1_2M    2               /* Bios                                */
#define  DRIVE_720K    3               /*                                     */
#define  DRIVE_1_44M   4               /*                                     */
#define  DRIVE_2_88M   5               /*                                     */
#define  DRIVE_UNKNOWN 6               /*                                     */
/*
Ŀ
 Macros                     

*/
#if defined(_QC) || defined(_MSC_VER)
#define w_isopen(window)               (((void far *)((WIN_PTR)(window))->opn)==(void far *)window)
#else
#define w_isopen(window)               ((WIN_PTR)(window)->opn==(void far *)window)
#endif
#define w_getborder()                  w_border
/*
Ŀ
 Structures                                                                   

*/
typedef struct WIN_DATA                /* Window structure                    */
{                                      /*                                     */
   int       row,                      /* Row                                 */
             col,                      /* Column                              */
             len,                      /* Length                              */
             hgt,                      /* Height                              */
             bdr,                      /* Border Type                         */
             shd,                      /* Shadow present                      */
             c_row,                    /* Window cursor row                   */
             c_col;                    /* Window cursor column                */
   void far *opn;                      /* Window open flag                    */
   char     *title;                    /* Window title                        */
   ATTRIBUTE color;                    /* Window color                        */
   char     *screen;                   /* Screen save buffer                  */
}  WINDOW;                             /*                                     */
typedef struct WIN_DATA *WIN_PTR;      /*                                     */

typedef struct                         /*                                     */
{                                      /*                                     */
    char word[25];                     /* Help key word                       */
    long offset;                       /* Offset within Help.hlp file         */
    int  num_lines;                    /* Number of lines of associated text  */
} HELP_ITEM;                           /*                                     */

typedef struct HELP_DATA               /*                                     */
{                                      /*                                     */
   int        num_keys;                /* Number of help words                */
   HELP_ITEM *help;                    /* Help words and help.hlp file offsets*/
} HELP;

/*
Ŀ
 Function Prototypes                                                          

*/
#if defined (_QC) || defined(_MSC_VER)
extern void w_fpe_handler(int sig_num,int fpe_code);
extern void far w_crit_err_handler(unsigned dev_err,unsigned err_val,
            unsigned far *dev_hdr);
#elif defined(__POWERC)
extern void w_fpe_handler(int sig_num);
extern int  w_crit_err_handler(unsigned err_val,unsigned dev_err,
            unsigned dev_seg,unsigned dev_off);
#else
extern void w_fpe_handler(int sig_num,int fpe_code,int *reg_list);
extern int  w_crit_err_handler(unsigned err_val,unsigned dev_err,
            unsigned dev_seg,unsigned dev_off);
#endif
extern int  w_clear(WIN_PTR window);
extern int  w_close(WIN_PTR);
extern void w_clrscrn(void);
extern void w_config(void);
extern void w_display_config(int row, int col);
extern void w_DOS_total(void);
extern void w_DOS_avail(void);
extern void w_EMS_total(void);
extern void w_EMS_avail(void);
extern void w_XMS_total(void);
extern void w_XMS_avail(void);
extern void w_VCPI_total(void);
extern void w_VCPI_avail(void);
extern void w_DPMI_memory(void);
extern int  w_edit(WIN_PTR window,ATTRIBUTE text_color,ATTRIBUTE block_color,
            int vir_wth,char **t_screen,int *t_num_lines,int edit,
			int new_file,int indicators,char *title,char *help_word);
extern unsigned int w_errbox(unsigned int error,...);
extern void w_exit(int exit_code);
extern void w_global(void);
extern void w_help(char *help_word);
extern void w_hscroll(WIN_PTR window,int dir,int num_lines);
extern void w_init(void);
extern void w_install_handlers(void);
extern int  w_move(WIN_PTR window, int dir,int num_cells);
extern WIN_PTR w_open(int r,int c,int h,int l,int border,int shadow,
                      ATTRIBUTE color,char *title);
extern void w_prtf(WIN_PTR window,char *format,...);
extern int  w_read_setup(void);
extern int  w_resize(WIN_PTR window, int rows, int cols);
extern void w_setborder(int border_type);
extern void w_vscroll(WIN_PTR window,int dir,int num_lines);
extern void w_setup(void);
extern char w_ynbox(char *prompt,char *help_word);
#if defined(__POWERC)                  /* Re-enable debug information for     */
#pragma trace                          /* Power Ctrace in source files.       */
#endif                                 /*                                     */
#endif
